@@ -840,7 +840,7 @@ def outputConfig(name, timePoints, gradient):
     df.to_csv(fname, index=False)
 
 
-def outputGradientFig(name, gradient, timePoints):
+def outputGradientFig(name, gradient, timePoints, fontsize=20):
     """
     Function to output the gradient figure in png.
 
@@ -852,13 +852,15 @@ def outputGradientFig(name, gradient, timePoints):
         Sequence of mobile phase percentages at all time points.
     timePoints: numpy array
         Sequence of time points.
+    fontsize: int
+        Font size of the figure.
     """
 
     plt.plot(timePoints, gradient, color="black", linewidth=1)
-    plt.xlabel("Retention time, min", fontname='Arial', fontsize=10, labelpad=2)
-    plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=10, labelpad=2)
-    plt.xticks(fontname='Arial', fontsize=10)
-    plt.yticks(np.arange(0, 120, 20), fontname='Arial', fontsize=10)
+    plt.xlabel("Retention time, min", fontname='Arial', fontsize=fontsize, labelpad=2)
+    plt.ylabel("Mobile phase, %", fontname='Arial', fontsize=fontsize, labelpad=2)
+    plt.xticks(fontname='Arial', fontsize=fontsize)
+    plt.yticks(np.arange(0, 120, 20), fontname='Arial', fontsize=fontsize)
     plt.savefig(fname=name, bbox_inches='tight')
     plt.close()
 
